@@ -1,9 +1,7 @@
 from dataclasses import dataclass
 
-from pxd_tree.adjacency_list import (
-    FieldsConfig as Base,
-    DEFAULT_FIELDS_CONFIG as BASE
-)
+from pxd_tree.adjacency_list.services.tree_collector import FieldsConfig as Base
+from pxd_tree.adjacency_list import DEFAULT_FIELDS_CONFIG as BASE
 
 
 __all__ = 'FieldsConfig', 'DEFAULT_FIELDS_CONFIG',
@@ -19,4 +17,4 @@ DEFAULT_FIELDS_CONFIG = FieldsConfig(
     parent=BASE.parent,
     parent_id=BASE.parent_id,
     path='path'
-)
\ No newline at end of file
+)
