@@ -4,7 +4,7 @@ from django.contrib.postgres.indexes import GistIndex
 from django.utils.translation import pgettext_lazy
 
 from pxd_postgres.ltree import LtreeIntField
-from pxd_tree.adjacency_list import Tree as BaseTree
+from pxd_tree.adjacency_list.models import Tree as BaseTree
 
 
 __all__ = 'Tree', 'tree_indexes',
